ryvencore.logging.LogsManager module - ryvencore v0.1.0 documentation

Hide navigation sidebar
Hide table of contents sidebar
Toggle table of contents sidebar

# ryvencore.logging.LogsManager module

class LogsManager(script, create_default_logs=True)

  Bases: `ryvencore.Base.Base`

  Manages all logs/loggers that belong to the script.

  new_logger_created = <ryvencore.Base.Event object>
  create_default_loggers()
  new_logger(title: str) → ryvencore.logging.Logger.Logger